@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # 设置管理域名 & 上传域名
-PUT_URL = 'http://apitest_user.up0.v1.wcsapi.com'
+PUT_URL = 'http://'
 MGR_URL = 'http://'
 
 # 设置分片上传的块大小和片大小，单位均为字节
